@@ -31,9 +31,7 @@
 
 #include <gmodule.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
 
