@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-greasemonkey-extension.c 1543 2007-07-12 12:25:06Z sbacher $
+ *  $Id$
  */
 
 #include "config.h"
@@ -28,22 +28,19 @@
 
 #include <epiphany/ephy-extension.h>
 #include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-embed-factory.h>
+#include <epiphany/ephy-embed-container.h>
 #include <epiphany/ephy-embed-event.h>
+#include <epiphany/ephy-embed-factory.h>
 #include <epiphany/ephy-embed-persist.h>
 #include <epiphany/ephy-shell.h>
-#include <epiphany/ephy-tab.h>
 #include <epiphany/ephy-window.h>
 
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkuimanager.h>
 
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-xfer.h>
-
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
+#include <gio/gio.h>
 #include <gmodule.h>
 
 #include <sys/stat.h>
@@ -60,7 +57,7 @@
 struct _EphyGreasemonkeyExtensionPrivate
 {
 	GHashTable *scripts;
-	GnomeVFSMonitorHandle *monitor;
+	GFileMonitor *monitor;
 };
 
 typedef struct
@@ -125,19 +122,19 @@ load_scripts (const char *path)
 		d = opendir (dirs[dir]);
 		if (d == NULL)
 		{
-			return scripts;
+			continue;
 		}
-		
+
 		while ((e = readdir (d)) != NULL)
 		{
 			if (g_str_has_suffix (e->d_name, ".user.js"))
 			{
 				file_path = g_build_filename (dirs[dir], e->d_name, NULL);
-				
+
 				script = greasemonkey_script_new (file_path);
 				g_hash_table_replace (scripts,
 						      g_strdup (e->d_name), script);
-				
+
 				g_free (file_path);
 			}
 		}
@@ -147,32 +144,34 @@ load_scripts (const char *path)
 }
 
 static void
-dir_changed_cb (GnomeVFSMonitorHandle *handle,
-		const char *monitor_uri,
-		const char *info_uri,
-		GnomeVFSMonitorEventType event_type,
+dir_changed_cb (GFileMonitor *monitor,
+		GFile *file,
+		GFile *other_file,
+		GFileMonitorEvent event,
 		EphyGreasemonkeyExtension *extension)
 {
+	char *uri;
 	char *path;
 	char *basename;
 	GreasemonkeyScript *script;
 
-	LOG ("Activity on %s", info_uri);
+	uri = g_file_get_uri (file);
+	path = g_file_get_path (file);
+	LOG ("Activity on %s", uri);
 
-	if (g_str_has_suffix (info_uri, ".user.js") == FALSE) return;
+	if (g_str_has_suffix (uri, ".user.js") == FALSE) return;
 
-	path = gnome_vfs_get_local_path_from_uri (info_uri);
-	basename = g_path_get_basename (path);
+	basename = g_file_get_basename (file);
 
-	switch (event_type)
+	switch (event)
 	{
-		case GNOME_VFS_MONITOR_EVENT_CREATED:
-		case GNOME_VFS_MONITOR_EVENT_CHANGED:
+		case G_FILE_MONITOR_EVENT_CREATED:
+		case G_FILE_MONITOR_EVENT_CHANGED:
 			script = greasemonkey_script_new (path);
 			g_hash_table_replace (extension->priv->scripts,
 					      g_strdup (basename), script);
 			break;
-		case GNOME_VFS_MONITOR_EVENT_DELETED:
+		case G_FILE_MONITOR_EVENT_DELETED:
 			g_hash_table_remove (extension->priv->scripts,
 					     basename);
 			break;
@@ -181,28 +180,29 @@ dir_changed_cb (GnomeVFSMonitorHandle *handle,
 	}
 
 	g_free (basename);
+	g_free (uri);
 	g_free (path);
 }
 
-static GnomeVFSMonitorHandle *
+static GFileMonitor *
 monitor_scripts (const char *path,
 		 EphyGreasemonkeyExtension *extension)
 {
-	char *uri;
-	GnomeVFSMonitorHandle *monitor;
-	GnomeVFSResult res;
+	GFileMonitor *monitor;
+	GFile *file;
 
-	uri = gnome_vfs_get_uri_from_local_path (path);
-	res = gnome_vfs_monitor_add (&monitor, path,
-				     GNOME_VFS_MONITOR_DIRECTORY,
-				     (GnomeVFSMonitorCallback) dir_changed_cb,
-				     extension);
-	g_free (uri);
-
-	if (res != GNOME_VFS_OK)
+	file = g_file_new_for_path (path);
+	monitor = g_file_monitor_directory (file,
+					    0, NULL, NULL);
+	if (monitor == NULL)
 	{
 		return NULL;
 	}
+	g_signal_connect (monitor, "changed",
+			  G_CALLBACK (dir_changed_cb),
+			  extension);
+
+	g_object_unref (file);
 
 	LOG ("Monitoring %s for user scripts", path);
 	return monitor;
@@ -219,7 +219,7 @@ ephy_greasemonkey_extension_init (EphyGreasemonkeyExtension *extension)
 
 	path = get_script_dir ();
 	errno = 0;
-	if ((g_mkdir_with_parents (path, 0700) >= 0) || 
+	if ((g_mkdir_with_parents (path, 0700) >= 0) ||
 	    (errno == EEXIST))
 	{
 		extension->priv->scripts = load_scripts (path);
@@ -243,7 +243,7 @@ ephy_greasemonkey_extension_finalize (GObject *object)
 
 	if (extension->priv->monitor != NULL)
 	{
-		gnome_vfs_monitor_cancel (extension->priv->monitor);
+		g_file_monitor_cancel (extension->priv->monitor);
 	}
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -277,6 +277,7 @@ save_source_cancelled_cb (EphyEmbedPersist *persist,
 {
 	WindowData *data;
 	const char *dest;
+	GFile *file;
 
 	LOG ("Download from %s cancelled",
 	     ephy_embed_persist_get_source (persist));
@@ -287,8 +288,10 @@ save_source_cancelled_cb (EphyEmbedPersist *persist,
 						 persist);
 
 	dest = ephy_embed_persist_get_dest (persist);
-	gnome_vfs_unlink (dest);
+	file = g_file_new_for_path (dest);
+	g_file_delete (file, NULL, NULL);
 
+	g_object_unref (file);
 	g_object_unref (G_OBJECT (persist));
 }
 
@@ -338,7 +341,7 @@ ephy_greasemonkey_extension_install_cb (GtkAction *action,
 	url = data->last_clicked_url;
 	g_return_if_fail (url != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
 	LOG ("Installing script at '%s'", url);
@@ -550,15 +553,10 @@ impl_detach_window (EphyExtension *ext,
 static void
 impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
-	EphyEmbed *embed;
-
 	LOG ("impl_attach_tab");
 
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_connect (embed, "ge_context_menu",
@@ -570,15 +568,10 @@ impl_attach_tab (EphyExtension *ext,
 static void
 impl_detach_tab (EphyExtension *ext,
 		 EphyWindow *window,
-		 EphyTab *tab)
+		 EphyEmbed *embed)
 {
-	EphyEmbed *embed;
-
 	LOG ("impl_detach_tab");
 
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	embed = ephy_tab_get_embed (tab);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
 	g_signal_handlers_disconnect_by_func
