@@ -30,10 +30,7 @@
 #include <epiphany/ephy-embed-container.h>
 #include <epiphany/ephy-notebook.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkstock.h>
+#include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
 
